#
# spec file for package librsync
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname   librsync2
Name:           librsync
Version:        1.0.0
Release:        lp152.3.5
Summary:        A Library for Generating Network Deltas
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://librsync.sourceforge.net/
Source:         https://github.com/librsync/%{name}/archive/v%{version}.tar.gz
Patch0:         librsync-0.9.7-strictalias.diff
Patch1:         librsync-man-example.diff
Patch2:         librsync-0.9.7-getopt.patch
Patch3:         librsync-exports.patch
Patch4:         blake2-config.patch
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  popt-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
librsync implements the "rsync" algorithm, which allows remote
differencing of binary files.  librsync computes a delta relative to a
file's checksum, so the two files need not both be present to generate
a delta.

%package -n %{lname}
Summary:        A Library for Generating Network Deltas
Group:          System/Libraries
# O/P added 2011-11-26
Obsoletes:      librsync < %{version}-%{release}
Provides:       librsync = %{version}-%{release}

%description -n %{lname}
librsync implements the "rsync" algorithm, which allows remote
differencing of binary files.  librsync computes a delta relative to a
file's checksum, so the two files need not both be present to generate
a delta.

%package devel
Summary:        Development files for librsync
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
librsync implements the "rsync" algorithm, which allows remote
differencing of binary files.  librsync computes a delta relative to a
file's checksum, so the two files need not both be present to generate
a delta.

%package -n rdiff
Summary:        Frontend to rsync's delta algorithm
Group:          Productivity/Archiving/Backup

%description -n rdiff
rdiff computes and applies signature-based file differences.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
autoreconf -fvi
%configure \
   --enable-shared \
   --disable-static \
   --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm %{buildroot}%{_libdir}/*.la

%check
make %{?_smp_mflags} check

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/librsync.so.*
%doc AUTHORS COPYING NEWS README.md THANKS TODO.md

%files devel
%defattr(-,root,root)
%{_libdir}/librsync.so
%{_mandir}/man3/*
%{_includedir}/*.h

%files -n rdiff
%defattr(-,root,root)
%{_bindir}/rdiff
%{_mandir}/man1/*

%changelog
* Mon Mar 23 2015 schwab@linux-m68k.org
- blake2-config.patch: add missing <config.h>
* Mon Feb 16 2015 tchvatal@suse.com
- Version bump to 1.0.0 fixes bnc#900914 CVE-2014-8242:
  * Various build fixes, thanks Timothy Gu.
  * Improved rdiff man page from Debian.
  * Fixed bug #1110812 'internal error: job made no progress'; on large
    files.
  * Moved hosting to https://github.com/librsync/librsync/
  * Travis-CI.org integration test at https://travis-ci.org/librsync/librsync/
  * Remove bundled copy of popt; it must be installed separately.
- Refreshed patches:
  * librsync-man-example.diff
- Removed patches:
  * librsync-noexecstack-nestedfunc.patch
  * librsync-serial-tests.patch
  * librsync-logn-sumset.patch
  * librsync-logn-search.patch
- Removed patches due to promoting bugs:
  * librsync-0.9.7-largefiles.patch - currently in progress on:
    https://github.com/librsync/librsync/pull/14
* Sat Sep 13 2014 crrodriguez@opensuse.org
- Library ends compiled with executable stack, something we really
  do not want around.. it turns out a nested function causes gcc
  to emit trampolines. fix that (librsync-noexecstack-nestedfunc.patch)
- Only export the public api, all symbols prefixed with "rs_"
  (librsync-exports.patch)
* Wed May 14 2014 tchvatal@suse.com
- Remove accidentaly added file.
* Tue May 13 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Add patch librsync-0.9.7-getopt.patch fixing debian bug#435894
  * makes rdiff avare of -i and -z getopt options
* Thu May  2 2013 crrodriguez@opensuse.org
- librsync-serial-tests.patch fix build with new automake
* Fri Mar 15 2013 hpj@urpla.net
- apply librsync-logn-search.patch, librsync-logn-sumset.patch
  librsync-man-example.diff
- refresh all patches
- enable tests
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Employ shlib packaging
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Sep  2 2007 crrodriguez@suse.de
- library was unable to handle files larger than 4GB properly (librsync-0.9.7-largefiles.patch)
- fix build dependencies
* Sat Aug 25 2007 crrodriguez@suse.de
- spec cleanup
- stop using bundled popt library, use system one
- enable shared library
- disable static library
- remove libtool archive
* Sat Mar 24 2007 rguenther@suse.de
- add libbz2-devel and zlib-devel BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Thu Apr 14 2005 cthiel@suse.de
- update to 0.9.7
* Fri Feb  6 2004 garloff@suse.de
- Fix strict aliasing issues.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sun Aug 17 2003 garloff@suse.de
- Reenable installation of rdiff tool.
- Update to 0.9.6:
  * Large file support fixes.
  * [v]snprintf or _[v]snprintf autoconf replacement function fix.
  * Changed installed include file from rsync.h to librsync.h.
  * Rollsum bugfix that produces much smaller deltas.
  * Memory leaks bugfix patches.
  * mdfour bigendian and >512M bugfix, plus optimisations patch.
  * autoconf/automake updates and cleanups for autoconf 2.53.
* Fri Aug 16 2002 ro@suse.de
- removed empty post/postun scripts (#17922)
* Tue Jan 29 2002 schwab@suse.de
- Build with -fPIC so that it can be included in a shared library.
- Fix unaligned accesses.
* Mon Jan 28 2002 garloff@suse.de
- Fix building for s390x by using %%{_libdir}
* Fri Jan 18 2002 garloff@suse.de
- Update to 0.9.5 (moved from samba.org to sourceforge apparently)
* Thu Jan 17 2002 garloff@suse.de
- Initial creation of package (0.9.3)
